#[non_exhaustive]pub struct ResolvedToken {
pub range: Range<usize>,
pub token_type: SemanticTokenType,
pub modifiers: SemanticTokenModifiers,
}Expand description
A semantic token resolved to absolute byte coordinates (pre delta-encoding).
#[non_exhaustive] so fields can be added without breaking downstream matches.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.range: Range<usize>Byte range of the token in the source.
token_type: SemanticTokenTypeThe LSP semantic token type this token maps to.
modifiers: SemanticTokenModifiersThe LSP semantic token modifiers (a bitset) for this token.